pub struct Table { /* private fields */ }Expand description
A Type1 font table.
Implementations
Sourceimpl Table
impl Table
Sourcepub fn is_multiple_master(&self) -> bool
pub fn is_multiple_master(&self) -> bool
Returns whether this is a MultipleMaster font.
Sourcepub fn outline(
&self,
string: &str,
builder: &mut dyn OutlineBuilder,
) -> Option<()>
pub fn outline( &self, string: &str, builder: &mut dyn OutlineBuilder, ) -> Option<()>
Outlines a glyph.
Sourcepub fn glyph_width(&self, string: &str) -> Option<f32>
pub fn glyph_width(&self, string: &str) -> Option<f32>
Returns the raw charstring advance width for a glyph name.
Sourcepub fn code_to_string(&self, code_point: u8) -> Option<&str>
pub fn code_to_string(&self, code_point: u8) -> Option<&str>
Return the glyph name of the code point.
Sourcepub fn charstring_names(&self) -> &[String]
pub fn charstring_names(&self) -> &[String]
Returns charstring names in their original insertion order.
Sourcepub fn charstring_index(&self, name: &str) -> Option<u16>
pub fn charstring_index(&self, name: &str) -> Option<u16>
Returns the insertion index of a charstring by name.