Scanner

Struct Scanner 

pub struct Scanner<'a> { /* private fields */ }
A PostScript scanner that parses Objects from a byte stream.

Implementations

Source

impl<'a> Scanner<'a>

pub fn new(data: &'a [u8]) -> Self

Create a new scanner over the given bytes of a PostScript program.

pub fn at_end(&mut self) -> bool

Returns true if there are no more objects to parse.

pub fn parse_object(&mut self) -> Result<Object<'a>>

Parse the next object.

pub fn parse_number(&mut self) -> Result<Number>

Parse the next object as a Number.

pub fn parse_name(&mut self) -> Result<Name<'a>>

Parse the next object as a Name.

pub fn parse_string(&mut self) -> Result<String<'a>>

Parse the next object as a String.

pub fn parse_array(&mut self) -> Result<Array<'a>>

Parse the next object as an Array.